@@ -53,11 +53,11 @@ enum AT_histo_type{
  * @param[out] left_limit            left limit of bin
  * @return     status code
  */
-int AT_histo_linear_left_limit(      const long number_of_bins,
+int AT_histo_linear_left_limit( const long number_of_bins,
                                 const double lowest_left_limit,
                                 const double step,
                                 const long bin_no,
-                                double * left_limit);
+                                double* left_limit);
 
 
 /**
@@ -73,7 +73,7 @@ int AT_histo_logarithmic_left_limit(      const long number_of_bins,
                                 const double lowest_left_limit,
                                 const double step,
                                 const long bin_no,
-                                double * left_limit);
+                                double* left_limit);
 
 
 /**
@@ -92,7 +92,7 @@ int AT_histo_left_limit( const long number_of_bins,
     const double step,
     const long histo_type,
     const long bin_no,
-    double * left_limit);
+    double* left_limit);
 
 
 /**
@@ -141,7 +141,7 @@ int AT_histo_logarithmic_bin_width(      const long number_of_bins,
                                 const double lowest_left_limit,
                                 const double step,
                                 const long bin_no,
-                                double * bin_width);
+                                double* bin_width);
 
 
 /**
@@ -160,7 +160,7 @@ int AT_histo_bin_width(      const long number_of_bins,
                                 const double step,
                                 const long histo_type,
                                 const long bin_no,
-                                double * bin_width);
+                                double* bin_width);
 
 
 /**
@@ -191,11 +191,11 @@ int AT_histo_bin_widths( const long number_of_bins,
  * @param[out] midpoint              midpoint of bin
  * @return status code
  */
-int AT_histo_linear_midpoint(      const long number_of_bins,
+int AT_histo_linear_midpoint(   const long number_of_bins,
                                 const double lowest_left_limit,
                                 const double step,
                                 const long bin_no,
-                                double * midpoint);
+                                double* midpoint);
 
 
 /**
@@ -211,7 +211,7 @@ int AT_histo_logarithmic_midpoint(      const long number_of_bins,
                                 const double lowest_left_limit,
                                 const double step,
                                 const long bin_no,
-                                double * midpoint);
+                                double* midpoint);
 
 
 /**
@@ -230,7 +230,7 @@ int AT_histo_midpoint(      const long number_of_bins,
                                 const double step,
                                 const long histo_type,
                                 const long bin_no,
-                                double * midpoint);
+                                double* midpoint);
 
 
 /**
@@ -262,7 +262,7 @@ int AT_histo_midpoints( const long number_of_bins,
 int AT_histo_linear_step(      const long number_of_bins,
                                 const double lowest_left_limit,
                                 const double highest_left_limit,
-                                double * step);
+                                double* step);
 
 /**
  * Returns step for given range for logarithmic histograms
@@ -275,7 +275,7 @@ int AT_histo_linear_step(      const long number_of_bins,
 int AT_histo_logarithmic_step(      const long number_of_bins,
                                 const double lowest_left_limit,
                                 const double highest_left_limit,
-                                double * step);
+                                double* step);
 
 /**
  * Returns step for given range
@@ -291,7 +291,7 @@ int AT_histo_step(      const long number_of_bins,
                         const double lowest_left_limit,
                         const double highest_left_limit,
                         const long histo_type,
-                        double * step);
+                        double* step);
 
 ///////////////////////////////// Number of bin routines ////////////////////////////////////
 /**
@@ -305,7 +305,7 @@ int AT_histo_step(      const long number_of_bins,
 int AT_histo_linear_n_bins(     const double lowest_left_limit,
                                 const double highest_left_limit,
                                 const double step,
-                                long * number_of_bins);
+                                long* number_of_bins);
 
 /**
  * Returns number of bins for given range for logarithmic histograms
@@ -318,7 +318,7 @@ int AT_histo_linear_n_bins(     const double lowest_left_limit,
 int AT_histo_logarithmic_n_bins(     const double lowest_left_limit,
                                 const double highest_left_limit,
                                 const double step,
-                                long * number_of_bins);
+                                long* number_of_bins);
 
 /**
  * Returns number of bins for given range for logarithmic histograms
@@ -334,7 +334,7 @@ int AT_histo_n_bins(     const double lowest_left_limit,
     const double highest_left_limit,
     const double step,
     const long histo_type,
-    long * number_of_bins);
+    long* number_of_bins);
 
 ///////////////////////////////// Access routines ////////////////////////////////////
 /**
@@ -391,15 +391,14 @@ long AT_histo_bin_no(      const long number_of_bins,
  * @see AT_histo_type
  * @param[in] value                value
  * @param[in] weight               weight by which the bin frequency content for 'value' is increase (usually 1)
- * @param[in,out] frequency        vector of frequencies for the histogram
- * length number_of_bins
+ * @param[in,out] frequency        vector of frequencies for the histogram (array of number_of_bins)
  */
 void AT_histo_add_single(      const long number_of_bins,
     const double lowest_left_limit,
     const double step,
     const long histo_type,
-    const double values,
-    const double weights,
+    const double value,
+    const double weight,
     double frequency[]);
 
 /**
@@ -410,11 +409,10 @@ void AT_histo_add_single(      const long number_of_bins,
  * @param[in] step                 step between bin limits
  * @param[in] histo_type           type of histogram (linear or logarithmic)
  * @see AT_histo_type
- * @param[in] number_of_values     number of values given
- * @param[in] values               values (array of size number_of_values)
- * @param[in] weights              weights by which the bin frequency content for 'value' is increase (array of size number_of_values)
- * @param[in,out] frequency        vector of frequencies for the histogram
- * length number_of_bins
+ * @param[in] n_values             number of values given
+ * @param[in] value                values (array of size number_of_values)
+ * @param[in] weight               weights by which the bin frequency content for 'value' is increase (array of size number_of_values)
+ * @param[in,out] frequency        vector of frequencies for the histogram (array of size number_of_bins)
  */
 void AT_histo_add_multi(      const long number_of_bins,
     const double lowest_left_limit,
@@ -427,12 +425,12 @@ void AT_histo_add_multi(      const long number_of_bins,
 
 /**
  * TODO
- * @param number_of_bins
- * @param lowest_left_limit
- * @param step
- * @param histo_type
- * @param frequency
- * @param sum
+ * @param[in] number_of_bins
+ * @param[in] lowest_left_limit
+ * @param[in] step
+ * @param[in] histo_type
+ * @param[in] frequency (array of size number_of_bins)
+ * @param[out] sum
  */
 void AT_histo_sum(	const long number_of_bins,
 		const double lowest_left_limit,
@@ -444,11 +442,11 @@ void AT_histo_sum(	const long number_of_bins,
 
 /**
  * TODO
- * @param number_of_bins
- * @param lowest_left_limit
- * @param step
- * @param histo_type
- * @param frequency
+ * @param[in] number_of_bins
+ * @param[in] lowest_left_limit
+ * @param[in] step
+ * @param[in] histo_type
+ * @param[out] frequency  (array of size number_of_bins)
  */
 void AT_histo_normalize(	const long number_of_bins,
 		const double lowest_left_limit,
@@ -457,9 +455,19 @@ void AT_histo_normalize(	const long number_of_bins,
 		double frequency[]);
 
 /* TRANSIENT ROUTINES FOR TRANSFORMING OLD-STYLE KELLERER HISTOGRAMS INTO NEW STYLE */
-double AT_N2_to_step(double N2);
+/**
+ * TODO
+ * @param[in] N2
+ * @return step
+ */
+double AT_N2_to_step( double N2 );
 
-double AT_step_to_N2(double step);
+/**
+ * TODO
+ * @param[in] step
+ * @return N2
+ */
+double AT_step_to_N2( double step );
 
 
 /* OLD ROUTINES, KEPT FOR COMPATIBILITY */
@@ -518,7 +526,7 @@ double AT_histoOld_get_bin_width(	const long number_of_bins,
  *
  * @param[in] number_of_bins               number of bin in histogram
  * @param[in] bin_centers                  bin centers (array of size number_of_bins)
- * @param[out] bin_width                   resulting bin widths (array of size number_of_bins)
+ * @param[out] bin_widths                  resulting bin widths (array of size number_of_bins)
  */
 void AT_histoOld_get_bin_widths(	const long number_of_bins,
 								const double bin_centers[],
